'use strict';

var backendPluginApi = require('@backstage/backend-plugin-api');
var integration = require('@backstage/integration');
var types = require('@backstage/types');
var octokit = require('octokit');

class OctokitProviderImpl {
  #integrations;
  #githubCredentials;
  #octokitCache;
  #octokitCacheTtl;
  constructor(config) {
    this.#integrations = integration.ScmIntegrations.fromConfig(config);
    this.#githubCredentials = integration.DefaultGithubCredentialsProvider.fromIntegrations(
      this.#integrations
    );
    this.#octokitCache = /* @__PURE__ */ new Map();
    this.#octokitCacheTtl = { hours: 1 };
  }
  async getOctokit(url) {
    const integration = this.#integrations.github.byUrl(url);
    if (!integration) {
      throw new Error(`No integration found for url: ${url}`);
    }
    const key = integration.config.host;
    if (this.#octokitCache.has(key)) {
      return this.#octokitCache.get(key);
    }
    const { createCallbackAuth } = await import('@octokit/auth-callback');
    const octokit$1 = new octokit.Octokit({
      baseUrl: integration.config.apiBaseUrl,
      authStrategy: createCallbackAuth,
      auth: {
        callback: async () => {
          try {
            const credentials = await this.#githubCredentials.getCredentials({
              url
            });
            return credentials.token;
          } catch {
            return void 0;
          }
        }
      }
    });
    this.#octokitCache.set(key, octokit$1);
    setTimeout(() => {
      this.#octokitCache.delete(key);
    }, types.durationToMilliseconds(this.#octokitCacheTtl));
    return octokit$1;
  }
}
const octokitProviderServiceRef = backendPluginApi.createServiceRef({
  id: "octokitProvider",
  scope: "root",
  defaultFactory: async (service) => backendPluginApi.createServiceFactory({
    service,
    deps: { config: backendPluginApi.coreServices.rootConfig },
    async factory({ config }) {
      return new OctokitProviderImpl(config);
    }
  })
});

exports.octokitProviderServiceRef = octokitProviderServiceRef;
//# sourceMappingURL=octokitProviderService.cjs.js.map
